@@ -4,190 +4,186 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.ui" line="20"/>
-        <location filename="../mainwindow.cpp" line="179"/>
+        <location filename="../src/mainwindow.ui" line="20"/>
+        <location filename="../src/mainwindow.cpp" line="198"/>
         <source>Custom Toolbox</source>
         <translation>カスタムツールボックス</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="63"/>
+        <location filename="../src/mainwindow.ui" line="63"/>
         <source>About this application</source>
         <translation>このアプリケーションについて</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="66"/>
+        <location filename="../src/mainwindow.ui" line="66"/>
         <source>About...</source>
         <translation>情報...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="73"/>
+        <location filename="../src/mainwindow.ui" line="73"/>
         <source>Alt+A</source>
         <translation>Alt+A</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="89"/>
+        <location filename="../src/mainwindow.ui" line="89"/>
         <source>Customize launcher</source>
         <translation>ランチャのカスタマイズ</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="92"/>
+        <location filename="../src/mainwindow.ui" line="92"/>
         <source>Edit</source>
         <translation>編集</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="99"/>
+        <location filename="../src/mainwindow.ui" line="99"/>
         <source>Alt+E</source>
         <translation>Alt+E</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="163"/>
+        <location filename="../src/mainwindow.ui" line="163"/>
         <source>Help</source>
         <translation>ヘルプ</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="170"/>
+        <location filename="../src/mainwindow.ui" line="170"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="183"/>
+        <location filename="../src/mainwindow.ui" line="183"/>
         <source>Close application</source>
         <translation>アプリの終了</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="186"/>
+        <location filename="../src/mainwindow.ui" line="186"/>
         <source>Close</source>
         <translation>閉じる</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="193"/>
+        <location filename="../src/mainwindow.ui" line="193"/>
         <source>Alt+C</source>
         <translation>Alt+C</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="308"/>
+        <location filename="../src/mainwindow.ui" line="308"/>
         <source>This is a custom launcher</source>
         <translation>これはカスタムランチャです</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="324"/>
+        <location filename="../src/mainwindow.ui" line="324"/>
         <source>Show this dialog at start up</source>
         <translation>起動時にこのダイヤログを表示する</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="346"/>
+        <location filename="../src/mainwindow.ui" line="346"/>
         <source>search</source>
         <translation>検索</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="231"/>
-        <location filename="../mainwindow.cpp" line="238"/>
+        <location filename="../src/mainwindow.cpp" line="250"/>
+        <location filename="../src/mainwindow.cpp" line="257"/>
         <source>Execution Error</source>
-        <translation type="unfinished"></translation>
+        <translation>実行時のエラー</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="231"/>
+        <location filename="../src/mainwindow.cpp" line="250"/>
         <source>Failed to execute command: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>次のコマンドの実行に失敗しました: %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="238"/>
+        <location filename="../src/mainwindow.cpp" line="257"/>
         <source>Failed to start program: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>次のプログラムの起動に失敗しました: %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="278"/>
+        <location filename="../src/mainwindow.cpp" line="297"/>
         <source>Open List File</source>
         <translation>リストファイルを開く</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="278"/>
+        <location filename="../src/mainwindow.cpp" line="297"/>
         <source>List Files (*.list)</source>
         <translation>リストファイル (*.list)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="280"/>
+        <location filename="../src/mainwindow.cpp" line="299"/>
         <source>File Selection Error</source>
         <translation>ファイルの選択エラー</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="280"/>
+        <location filename="../src/mainwindow.cpp" line="299"/>
         <source>No file selected. Application will now exit.</source>
         <translation>ファイルを選択していません。アプリケーションを終了します。</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="286"/>
-        <location filename="../mainwindow.cpp" line="519"/>
-        <location filename="../mainwindow.cpp" line="639"/>
+        <location filename="../src/mainwindow.cpp" line="305"/>
+        <location filename="../src/mainwindow.cpp" line="569"/>
+        <location filename="../src/mainwindow.cpp" line="722"/>
         <source>File Open Error</source>
         <translation>ファイルを開く際のエラー</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="287"/>
+        <location filename="../src/mainwindow.cpp" line="306"/>
         <source>Could not open file. Do you want to try again?</source>
         <translation>ファイルを開けません。再試行しますか？</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="511"/>
+        <location filename="../src/mainwindow.cpp" line="561"/>
         <source>File Not Found</source>
         <translation>ファイルが見つかりません</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="511"/>
+        <location filename="../src/mainwindow.cpp" line="561"/>
         <source>The file %1 does not exist.</source>
         <translation>ファイル %1 は存在しません。</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="519"/>
+        <location filename="../src/mainwindow.cpp" line="569"/>
         <source>Could not open file: </source>
         <translation>次のファイルを開けません: </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="586"/>
+        <location filename="../src/mainwindow.cpp" line="660"/>
         <source>Version:</source>
-        <translation type="unfinished"></translation>
+        <translation>バージョン:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="589"/>
+        <location filename="../src/mainwindow.cpp" line="663"/>
         <source>About %1</source>
         <translation> %1 について</translation>
     </message>
     <message>
-        <source>Version: </source>
-        <translation type="vanished">バージョン：</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="587"/>
+        <location filename="../src/mainwindow.cpp" line="661"/>
         <source>Custom Toolbox is a tool used for creating a custom launcher</source>
         <translation>カスタムツールボックスは、カスタムランチャの作成ツールです。</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="587"/>
+        <location filename="../src/mainwindow.cpp" line="661"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="590"/>
+        <location filename="../src/mainwindow.cpp" line="664"/>
         <source>%1 License</source>
         <translation>%1 ライセンス</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="597"/>
+        <location filename="../src/mainwindow.cpp" line="671"/>
         <source>%1 Help</source>
         <translation>%1 ヘルプ</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="639"/>
+        <location filename="../src/mainwindow.cpp" line="722"/>
         <source>Could not write file: %1</source>
         <translation>次のファイルに書き込めません：%1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="643"/>
+        <location filename="../src/mainwindow.cpp" line="726"/>
         <source>File Removal Error</source>
         <translation>ファイルの削除エラー</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="643"/>
+        <location filename="../src/mainwindow.cpp" line="726"/>
         <source>Could not remove file: %1</source>
         <translation>次のファイルを削除できません: %1</translation>
     </message>
@@ -195,48 +191,48 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../about.cpp" line="70"/>
+        <location filename="../src/about.cpp" line="70"/>
         <source>License</source>
         <translation>ライセンス</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="71"/>
-        <location filename="../about.cpp" line="81"/>
+        <location filename="../src/about.cpp" line="71"/>
+        <location filename="../src/about.cpp" line="81"/>
         <source>Changelog</source>
         <translation>更新履歴</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="72"/>
+        <location filename="../src/about.cpp" line="72"/>
         <source>Cancel</source>
         <translation>キャンセル</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="94"/>
+        <location filename="../src/about.cpp" line="94"/>
         <source>&amp;Close</source>
         <translation>閉じる(&amp;C)</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="70"/>
+        <location filename="../src/main.cpp" line="80"/>
         <source>This app can be used to create custom launchers: box of buttons/icons</source>
         <translation>このアプリでカスタムランチャ（ボタン/アイコンのボックス）を作成できます。</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="73"/>
+        <location filename="../src/main.cpp" line="83"/>
         <source>Don&apos;t show &apos;show this dialog at startup&apos; checkbox</source>
         <translation>「起動時にこのダイアログを表示する」チェックボックスを表示しない</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="75"/>
+        <location filename="../src/main.cpp" line="85"/>
         <source>Full path and name of the .list file you want to load to set up the application</source>
         <translation>アプリケーションのセットアップで読み込む .list ファイルのフルパスとファイル名</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="85"/>
+        <location filename="../src/main.cpp" line="95"/>
         <source>Error</source>
         <translation>エラー</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="86"/>
+        <location filename="../src/main.cpp" line="96"/>
         <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
         <translation>root としてログインしているようです。このプログラムを使用するには、一度ログアウトして通常のユーザとしてログインしてください。</translation>
     </message>
